// -*- mode: C++; c-file-style: "Stroustrup" -*-
//
// This file is part of krot,
// a program for the simulation, assignment and fit of HRLIF spectra.
//
// Copyright (C) 1998 Jochen Kpper
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; see the file License. if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 , USA
//
// If you use this program for your scientific work, please cite it according to
// the file CITATION that comes with the package.
//
// $Id: spectrum.h,v 1.3 1998/10/09 17:57:27 jochen Exp $



#ifndef KROT_SPECTRUM_H
#define KROT_SPECTRUM_H



#include "dataset.h"
#include "rawData.h"

#include <string>



class KRotData;



/**
 * Provides a container for spectra.
 *
 * @short Spectrum container.
 * @author Jochen Kpper
 * @version $Id: spectrum.h,v 1.3 1998/10/09 17:57:27 jochen Exp $
 */
class Spectrum : virtual public DataSet
{

public:

    /**
     * Standard Constructor.
     */
    Spectrum( KRotData *krotdata=0 );

    /**
     * Constructor.
     *
     * Create new Spectrum from imported data.
     *
     * @param import Imported data. All marker positions and one absolute
     * frequency need to be know already.
     */
    Spectrum( const RawData& import, KRotData *g );


protected:

  /**
   * load spectral data from an xy-file.
   *
   * @param filename The fully qualified filename to load the data from.
   * @return True on success, false on any error.
   */
  virtual bool loadXY( const QString& filename );
};



#endif
